summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--doc/src/debugger/creator-debugger.qdoc2
-rw-r--r--doc/src/editors/creator-coding.qdoc2
-rw-r--r--src/libs/3rdparty/cplusplus/Token.h4
-rw-r--r--src/libs/3rdparty/cplusplus/TranslationUnit.cpp2
-rw-r--r--src/libs/cplusplus/pp-engine.cpp6
-rw-r--r--src/libs/qtcreatorcdbext/symbolgroupvalue.cpp4
-rw-r--r--src/libs/utils/fileutils.cpp2
-rw-r--r--src/libs/utils/json.cpp2
-rw-r--r--src/libs/utils/qtcprocess.cpp2
-rw-r--r--src/plugins/android/androidmanifesteditorwidget.cpp2
-rw-r--r--src/plugins/autotoolsprojectmanager/makefileparserthread.h2
-rw-r--r--src/plugins/clearcase/clearcaseplugin.cpp2
-rw-r--r--src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp2
-rw-r--r--src/plugins/cpptools/cppcodeformatter.cpp2
-rw-r--r--src/plugins/cpptools/cppmodelmanager.cpp2
-rw-r--r--src/plugins/debugger/cdb/cdbengine.cpp2
-rw-r--r--src/plugins/debugger/gdb/gdbengine.cpp2
-rw-r--r--src/plugins/fakevim/fakevimhandler.cpp2
-rw-r--r--src/plugins/git/gitclient.cpp4
-rw-r--r--src/plugins/git/gitorious/gitoriousrepositorywizardpage.cpp2
-rw-r--r--src/plugins/projectexplorer/miniprojecttargetselector.cpp4
-rw-r--r--src/plugins/projectexplorer/projectnodes.h2
-rw-r--r--src/plugins/projectexplorer/wincetoolchain.cpp2
-rw-r--r--src/plugins/qmakeprojectmanager/qmakebuildconfiguration.cpp2
-rw-r--r--src/plugins/qmldesigner/designercore/model/modelnode.cpp4
-rw-r--r--src/plugins/qtsupport/qtversionmanager.cpp2
-rw-r--r--src/plugins/texteditor/basetextmark.cpp2
-rw-r--r--src/plugins/vcsbase/vcsbasesubmiteditor.cpp2
-rw-r--r--tests/system/shared/hook_utils.py2
-rw-r--r--tests/system/shared/utils.py6
-rw-r--r--tests/system/shared/workarounds.py4
-rw-r--r--tests/system/suite_editors/tst_qml_indent/test.py2
32 files changed, 42 insertions, 42 deletions
diff --git a/doc/src/debugger/creator-debugger.qdoc b/doc/src/debugger/creator-debugger.qdoc
index 8707150c72..45f01ed53a 100644
--- a/doc/src/debugger/creator-debugger.qdoc
+++ b/doc/src/debugger/creator-debugger.qdoc
@@ -662,7 +662,7 @@
Also, the debugger displays access data for QFileInfo and provides
access to the "real" contents of QVariant.
- Right-click in the the \gui{Locals and Expressions} view to open a context
+ Right-click in the \gui{Locals and Expressions} view to open a context
menu that provides additional options for viewing data. The available
options depend on the type of the current items, and are provided by the
\l{Using Debugging Helpers}{Debugging Helpers}. Typically, string-like data,
diff --git a/doc/src/editors/creator-coding.qdoc b/doc/src/editors/creator-coding.qdoc
index a3b3874a0e..38ae2ec906 100644
--- a/doc/src/editors/creator-coding.qdoc
+++ b/doc/src/editors/creator-coding.qdoc
@@ -58,7 +58,7 @@
\li \l{Configuring the Editor}
You can change the fonts, colors, highlighting, and indentation.
- If you are used to the the Vim editor, you can even run the main
+ If you are used to the Vim editor, you can even run the main
editor in a manner similar to it in the \gui{FakeVim} mode.
\endlist
diff --git a/src/libs/3rdparty/cplusplus/Token.h b/src/libs/3rdparty/cplusplus/Token.h
index 58fcee3a48..8889df0653 100644
--- a/src/libs/3rdparty/cplusplus/Token.h
+++ b/src/libs/3rdparty/cplusplus/Token.h
@@ -336,7 +336,7 @@ public:
unsigned kind : 8;
// The token starts a new line.
unsigned newline : 1;
- // The token is preceeded by whitespace(s).
+ // The token is preceded by whitespace(s).
unsigned whitespace : 1;
// The token is joined with the previous one.
unsigned joined : 1;
@@ -354,7 +354,7 @@ public:
unsigned generated : 1;
// Unused...
unsigned pad : 3;
- // The token lenght.
+ // The token length.
unsigned length : 16;
};
union {
diff --git a/src/libs/3rdparty/cplusplus/TranslationUnit.cpp b/src/libs/3rdparty/cplusplus/TranslationUnit.cpp
index 9d949acbcf..f37ef6a242 100644
--- a/src/libs/3rdparty/cplusplus/TranslationUnit.cpp
+++ b/src/libs/3rdparty/cplusplus/TranslationUnit.cpp
@@ -197,7 +197,7 @@ void TranslationUnit::tokenize()
if (tk.is(T_TILDE)) {
lex(&tk);
- // Get the total number of generated tokens and specifiy "null"
+ // Get the total number of generated tokens and specify "null"
// information for them.
unsigned totalGenerated =
static_cast<unsigned>(strtoul(tk.spell(), 0, 0));
diff --git a/src/libs/cplusplus/pp-engine.cpp b/src/libs/cplusplus/pp-engine.cpp
index f001be2c69..62100ce717 100644
--- a/src/libs/cplusplus/pp-engine.cpp
+++ b/src/libs/cplusplus/pp-engine.cpp
@@ -976,7 +976,7 @@ bool Preprocessor::handleIdentifier(PPToken *tk)
QVector<PPToken> body = macro->definitionTokens();
- // Withing nested expansion we might reach a previously added marker token. In this case,
+ // Within nested expansion we might reach a previously added marker token. In this case,
// we need to move it from its current possition to outside the nesting.
PPToken oldMarkerTk;
@@ -1837,13 +1837,13 @@ void Preprocessor::handleElifDirective(PPToken *tk, const PPToken &poundToken)
m_state.m_skipping[m_state.m_ifLevel] = true;
} else if (m_state.m_trueTest[m_state.m_ifLevel]) {
if (!m_state.m_skipping[m_state.m_ifLevel]) {
- // start skipping because the preceeding then-part was not skipped
+ // start skipping because the preceding then-part was not skipped
m_state.m_skipping[m_state.m_ifLevel] = true;
if (m_client)
startSkippingBlocks(poundToken);
}
} else {
- // preceeding then-part was skipped, so calculate if we should start
+ // preceding then-part was skipped, so calculate if we should start
// skipping, depending on the condition
Value result;
evalExpression(tk, result);
diff --git a/src/libs/qtcreatorcdbext/symbolgroupvalue.cpp b/src/libs/qtcreatorcdbext/symbolgroupvalue.cpp
index d7ccf2f84e..b443232a64 100644
--- a/src/libs/qtcreatorcdbext/symbolgroupvalue.cpp
+++ b/src/libs/qtcreatorcdbext/symbolgroupvalue.cpp
@@ -1793,7 +1793,7 @@ static bool dumpQStringFromQPrivateClass(const SymbolGroupValue &v,
v.node()->symbolGroup()->addSymbol(v.module(), symbolName, std::string(), &errorMessage);
if (!stringNode && errorMessage.find("DEBUG_ANY_ID") != std::string::npos) {
// HACK:
- // In some rare cases the the AddSymbol can't create a node with a given module name,
+ // In some rare cases the AddSymbol can't create a node with a given module name,
// but is able to add the symbol without any modulename.
dumpType = QtInfo::get(v.context()).prependModuleAndNameSpace("QString", "", QtInfo::get(v.context()).nameSpace);
symbolName = SymbolGroupValue::pointedToSymbolName(stringAddress , dumpType);
@@ -2557,7 +2557,7 @@ static bool dumpQVariant(const SymbolGroupValue &v, std::wostream &str, void **s
if (const SymbolGroupValue sv = dataV.typeCast(qtInfo.prependQtCoreModule("QString *").c_str())) {
if (!dumpQString(sv, str)) {
// HACK:
- // In some rare cases the the AddSymbol can't create a node with a given module name,
+ // In some rare cases the AddSymbol can't create a node with a given module name,
// but is able to add the symbol without any modulename.
if (const SymbolGroupValue svc = dataV.typeCast("QString *"))
dumpQString(svc, str);
diff --git a/src/libs/utils/fileutils.cpp b/src/libs/utils/fileutils.cpp
index 55154004d7..fa588c8ff1 100644
--- a/src/libs/utils/fileutils.cpp
+++ b/src/libs/utils/fileutils.cpp
@@ -514,7 +514,7 @@ QString FileName::toUserOutput() const
/// Find the parent directory of a given directory.
-/// Returns an empty FileName if the current dirctory is already
+/// Returns an empty FileName if the current directory is already
/// a root level directory.
/// \returns \a FileName with the last segment removed.
diff --git a/src/libs/utils/json.cpp b/src/libs/utils/json.cpp
index e4822a4dc2..524c2e00cf 100644
--- a/src/libs/utils/json.cpp
+++ b/src/libs/utils/json.cpp
@@ -89,7 +89,7 @@ QString JsonValue::kindToString(JsonValue::Kind kind)
if (kind == Null)
return QLatin1String("null");
- return QLatin1String("unkown");
+ return QLatin1String("unknown");
}
JsonValue *JsonValue::build(const QVariant &variant, JsonMemoryPool *pool)
diff --git a/src/libs/utils/qtcprocess.cpp b/src/libs/utils/qtcprocess.cpp
index 804bb8e8ed..5410e75aec 100644
--- a/src/libs/utils/qtcprocess.cpp
+++ b/src/libs/utils/qtcprocess.cpp
@@ -680,7 +680,7 @@ void QtcProcess::start()
qWarning("QtcProcess::start: Empty environment set when running '%s'.", qPrintable(m_command));
env = m_environment;
- // If the process environemnt has no libraryPath,
+ // If the process environment has no libraryPath,
// Qt will copy creator's libraryPath into the process environment.
// That's brain dead, and we work around it
if (osType != OsTypeWindows) { // a.k.a "Unixoid"
diff --git a/src/plugins/android/androidmanifesteditorwidget.cpp b/src/plugins/android/androidmanifesteditorwidget.cpp
index 39534f0c2d..4edea40f16 100644
--- a/src/plugins/android/androidmanifesteditorwidget.cpp
+++ b/src/plugins/android/androidmanifesteditorwidget.cpp
@@ -499,7 +499,7 @@ bool AndroidManifestEditorWidget::open(QString *errorString, const QString &file
return true;
}
}
- // some error occured
+ // some error occurred
updateInfoBar(error, errorLine, errorColumn);
setActivePage(Source);
return true;
diff --git a/src/plugins/autotoolsprojectmanager/makefileparserthread.h b/src/plugins/autotoolsprojectmanager/makefileparserthread.h
index fb268497b2..1489fe2e9c 100644
--- a/src/plugins/autotoolsprojectmanager/makefileparserthread.h
+++ b/src/plugins/autotoolsprojectmanager/makefileparserthread.h
@@ -111,7 +111,7 @@ public:
bool hasError() const;
/**
- * @return True, if the the has been cancelled by MakefileParserThread::cancel().
+ * @return True, if the parsing has been cancelled by MakefileParserThread::cancel().
*/
bool isCanceled() const;
diff --git a/src/plugins/clearcase/clearcaseplugin.cpp b/src/plugins/clearcase/clearcaseplugin.cpp
index 80d335619c..31932af280 100644
--- a/src/plugins/clearcase/clearcaseplugin.cpp
+++ b/src/plugins/clearcase/clearcaseplugin.cpp
@@ -1121,7 +1121,7 @@ void ClearCasePlugin::diffActivity()
// latest version - updated each line
filever[file].second = shortver;
- // pre-first version. only for the first occurence
+ // pre-first version. only for the first occurrence
if (filever[file].first.isEmpty()) {
int verpos = shortver.lastIndexOf(QRegExp(QLatin1String("[^0-9]"))) + 1;
int vernum = shortver.mid(verpos).toInt();
diff --git a/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp b/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
index ac7ae8a1b7..18355e7258 100644
--- a/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
+++ b/src/plugins/cmakeprojectmanager/cmakeopenprojectwizard.cpp
@@ -736,7 +736,7 @@ void CMakeRunPage::runCMake()
m_cmakeWizard->setKit(generatorInfo.kit());
m_cmakeWizard->setUseNinja(generatorInfo.isNinja());
- // If mode is initial the user chooses the kit, otherwise it's already choosen
+ // If mode is initial the user chooses the kit, otherwise it's already chosen
// and the environment already contains the kit
if (m_mode == Initial)
generatorInfo.kit()->addToEnvironment(env);
diff --git a/src/plugins/cpptools/cppcodeformatter.cpp b/src/plugins/cpptools/cppcodeformatter.cpp
index 543e0d4deb..d63fc49f43 100644
--- a/src/plugins/cpptools/cppcodeformatter.cpp
+++ b/src/plugins/cpptools/cppcodeformatter.cpp
@@ -231,7 +231,7 @@ void CodeFormatter::recalculateStateAfter(const QTextBlock &block)
switch (kind) {
case T_RBRACKET: turnInto(lambda_declarator_expected); break; // we can't determine exact kind of expression. Try again
case T_COMMA:
- case T_EQUAL: turnInto(lambda_instroducer); break; // ',' or '=' inside brackets can be only whithin lambda capture list
+ case T_EQUAL: turnInto(lambda_instroducer); break; // ',' or '=' inside brackets can be only within lambda capture list
case T_IDENTIFIER: // '&', id, 'this' are allowed both in the capture list and subscribtion
case T_AMPER:
case T_THIS: break;
diff --git a/src/plugins/cpptools/cppmodelmanager.cpp b/src/plugins/cpptools/cppmodelmanager.cpp
index 1363bef7b6..cec5b6772c 100644
--- a/src/plugins/cpptools/cppmodelmanager.cpp
+++ b/src/plugins/cpptools/cppmodelmanager.cpp
@@ -402,7 +402,7 @@ QByteArray CppModelManager::internalDefinedMacros() const
return macros;
}
-/// This function will aquire the mutex!
+/// This function will acquire the mutex!
void CppModelManager::dumpModelManagerConfiguration()
{
// Tons of debug output...
diff --git a/src/plugins/debugger/cdb/cdbengine.cpp b/src/plugins/debugger/cdb/cdbengine.cpp
index 893a168f6c..5e4f7ba038 100644
--- a/src/plugins/debugger/cdb/cdbengine.cpp
+++ b/src/plugins/debugger/cdb/cdbengine.cpp
@@ -1673,7 +1673,7 @@ void CdbEngine::handleResolveSymbol(const CdbBuiltinCommandPtr &command)
// Find the function address matching needle in a list of function
// addresses obtained from the 'x' command. Check for the
-// mimimum POSITIVE offset (needle >= function address.)
+// minimum POSITIVE offset (needle >= function address.)
static inline quint64 findClosestFunctionAddress(const QList<quint64> &addresses,
quint64 needle)
{
diff --git a/src/plugins/debugger/gdb/gdbengine.cpp b/src/plugins/debugger/gdb/gdbengine.cpp
index 13bf270f4a..89b52fde81 100644
--- a/src/plugins/debugger/gdb/gdbengine.cpp
+++ b/src/plugins/debugger/gdb/gdbengine.cpp
@@ -2563,7 +2563,7 @@ void GdbEngine::handleBreakInsert1(const GdbResponse &response)
const BreakpointModelId id = response.cookie.value<BreakpointModelId>();
if (handler->state(id) == BreakpointRemoveRequested) {
if (response.resultClass == GdbResultDone) {
- // This delete was defered. Act now.
+ // This delete was deferred. Act now.
const GdbMi mainbkpt = response.data["bkpt"];
handler->notifyBreakpointRemoveProceeding(id);
QByteArray nr = mainbkpt["number"].data();
diff --git a/src/plugins/fakevim/fakevimhandler.cpp b/src/plugins/fakevim/fakevimhandler.cpp
index 046f777b6e..25f0488cb2 100644
--- a/src/plugins/fakevim/fakevimhandler.cpp
+++ b/src/plugins/fakevim/fakevimhandler.cpp
@@ -3150,7 +3150,7 @@ void FakeVimHandler::Private::fixSelection()
if (g.movetype == MoveExclusive && g.subsubmode == NoSubSubMode) {
if (anchor() < position() && atBlockStart()) {
- // Exlusive motion ending at the beginning of line
+ // Exclusive motion ending at the beginning of line
// becomes inclusive and end is moved to end of previous line.
g.movetype = MoveInclusive;
moveToStartOfLine();
diff --git a/src/plugins/git/gitclient.cpp b/src/plugins/git/gitclient.cpp
index 507a11dbb4..1de0b04c41 100644
--- a/src/plugins/git/gitclient.cpp
+++ b/src/plugins/git/gitclient.cpp
@@ -3215,7 +3215,7 @@ bool GitClient::addAndCommit(const QString &repositoryDirectory,
filesToReset.append(newFile);
}
} else if (state & UnmergedFile && checked) {
- QTC_ASSERT(false, continue); // There should not be unmerged files when commiting!
+ QTC_ASSERT(false, continue); // There should not be unmerged files when committing!
}
if (state == ModifiedFile && checked) {
@@ -3231,7 +3231,7 @@ bool GitClient::addAndCommit(const QString &repositoryDirectory,
} else if (state == CopiedFile && checked) {
QTC_ASSERT(false, continue); // only is noticed after adding a new file to the index
} else if (state == UnmergedFile && checked) {
- QTC_ASSERT(false, continue); // There should not be unmerged files when commiting!
+ QTC_ASSERT(false, continue); // There should not be unmerged files when committing!
}
}
diff --git a/src/plugins/git/gitorious/gitoriousrepositorywizardpage.cpp b/src/plugins/git/gitorious/gitoriousrepositorywizardpage.cpp
index 621fe959bd..b8b59efa97 100644
--- a/src/plugins/git/gitorious/gitoriousrepositorywizardpage.cpp
+++ b/src/plugins/git/gitorious/gitoriousrepositorywizardpage.cpp
@@ -227,7 +227,7 @@ QString GitoriousRepositoryWizardPage::repositoryName() const
QUrl GitoriousRepositoryWizardPage::repositoryURL() const
{
- // Find by name (as we sorted the the repositories)
+ // Find by name (as we sorted the repositories)
const QString repoName = repositoryName();
foreach (const GitoriousRepository &r, m_projectPage->project()->repositories)
if (r.name == repoName)
diff --git a/src/plugins/projectexplorer/projectnodes.h b/src/plugins/projectexplorer/projectnodes.h
index f15de786bf..800008491d 100644
--- a/src/plugins/projectexplorer/projectnodes.h
+++ b/src/plugins/projectexplorer/projectnodes.h
@@ -319,7 +319,7 @@ public:
signals:
// everything
- // Emited whenever the model needs to send a update signal.
+ // Emitted whenever the model needs to send a update signal.
void nodeUpdated(ProjectExplorer::Node *node);
// projects
diff --git a/src/plugins/projectexplorer/wincetoolchain.cpp b/src/plugins/projectexplorer/wincetoolchain.cpp
index 6ccf071cd8..706e75e10a 100644
--- a/src/plugins/projectexplorer/wincetoolchain.cpp
+++ b/src/plugins/projectexplorer/wincetoolchain.cpp
@@ -95,7 +95,7 @@ static QString winExpandDelayedEnvReferences(QString in, const Utils::Environmen
pos = nextPos;
} else {
// Not sure about this, but we need to account for the case where
- // the end of the replacement doesn't have the directory seperator and
+ // the end of the replacement doesn't have the directory separator and
// neither does the start of the insert. This solution assumes:
// 1) Having \\ in a path is valid (it is on WinXP)
// 2) We're only replacing in paths. This will cause problems if there's
diff --git a/src/plugins/qmakeprojectmanager/qmakebuildconfiguration.cpp b/src/plugins/qmakeprojectmanager/qmakebuildconfiguration.cpp
index 6d5a67c6ac..7c3a0f807a 100644
--- a/src/plugins/qmakeprojectmanager/qmakebuildconfiguration.cpp
+++ b/src/plugins/qmakeprojectmanager/qmakebuildconfiguration.cpp
@@ -182,7 +182,7 @@ void QmakeBuildConfiguration::qtVersionsChanged(const QList<int> &,const QList<i
void QmakeBuildConfiguration::updateShadowBuild()
{
- // We also emit buildDirectoryChanged if the the Qt version's supportShadowBuild changed
+ // We also emit buildDirectoryChanged if the Qt version's supportShadowBuild changed
bool currentShadowBuild = supportsShadowBuilds();
if (currentShadowBuild != m_qtVersionSupportsShadowBuilds) {
if (!currentShadowBuild)
diff --git a/src/plugins/qmldesigner/designercore/model/modelnode.cpp b/src/plugins/qmldesigner/designercore/model/modelnode.cpp
index d41b600350..0f83f55608 100644
--- a/src/plugins/qmldesigner/designercore/model/modelnode.cpp
+++ b/src/plugins/qmldesigner/designercore/model/modelnode.cpp
@@ -617,7 +617,7 @@ void ModelNode::destroy()
/*!
- \brief Returns if the the two nodes reference the same entity in the same model
+ \brief Returns if the two nodes reference the same entity in the same model
*/
bool operator ==(const ModelNode &firstNode, const ModelNode &secondNode)
{
@@ -630,7 +630,7 @@ bool operator ==(const ModelNode &firstNode, const ModelNode &secondNode)
}
/*!
- \brief Returns if the the two nodes do not reference the same entity in the same model
+ \brief Returns if the two nodes do not reference the same entity in the same model
*/
bool operator !=(const ModelNode &firstNode, const ModelNode &secondNode)
{
diff --git a/src/plugins/qtsupport/qtversionmanager.cpp b/src/plugins/qtsupport/qtversionmanager.cpp
index dc9926f9c0..37e2cd3699 100644
--- a/src/plugins/qtsupport/qtversionmanager.cpp
+++ b/src/plugins/qtsupport/qtversionmanager.cpp
@@ -119,7 +119,7 @@ static QString findQMakeLine(const QString &makefile, const QString &key)
return QString();
}
-/// This function trims the "#Command /path/to/qmake" from the the line
+/// This function trims the "#Command /path/to/qmake" from the line
static QString trimLine(const QString line)
{
diff --git a/src/plugins/texteditor/basetextmark.cpp b/src/plugins/texteditor/basetextmark.cpp
index 6d4e06d913..538a849d6e 100644
--- a/src/plugins/texteditor/basetextmark.cpp
+++ b/src/plugins/texteditor/basetextmark.cpp
@@ -131,7 +131,7 @@ BaseTextMark::BaseTextMark(const QString &fileName, int lineNumber)
{
}
-// we need two phase initilization, since we are calling virtual functions
+// we need two phase initialization, since we are calling virtual functions
// of BaseTextMark in add() and also accessing widthFactor
// which might be set in the derived constructor
void BaseTextMark::init()
diff --git a/src/plugins/vcsbase/vcsbasesubmiteditor.cpp b/src/plugins/vcsbase/vcsbasesubmiteditor.cpp
index 08413d4cd1..e6d521c146 100644
--- a/src/plugins/vcsbase/vcsbasesubmiteditor.cpp
+++ b/src/plugins/vcsbase/vcsbasesubmiteditor.cpp
@@ -114,7 +114,7 @@ static const char *belongingClassName(const CPlusPlus::Function *function)
files from the list by pressing unchecking them or diff the selection
by doubleclicking.
- The action matching the the ids (unless 0) of the parameter struct will be
+ The action matching the ids (unless 0) of the parameter struct will be
registered with the EditorWidget and submit/diff actions will be added to
a toolbar.
diff --git a/tests/system/shared/hook_utils.py b/tests/system/shared/hook_utils.py
index ee2f05cdb8..1e63b7cf68 100644
--- a/tests/system/shared/hook_utils.py
+++ b/tests/system/shared/hook_utils.py
@@ -311,7 +311,7 @@ def deleteAppFromWinFW(workingDir, projectName, isReleaseBuild=True):
test.warning("Could not delete %s as allowed program from win firewall" % (projectName))
# helper that can modify the win firewall to allow a program to communicate through it or delete it
-# param addToFW defines whether to add (True) or delete (False) this programm to/from the firewall
+# param addToFW defines whether to add (True) or delete (False) this program to/from the firewall
def __configureFW__(workingDir, projectName, isReleaseBuild, addToFW=True):
if isReleaseBuild == None:
if projectName[-4:] == ".exe":
diff --git a/tests/system/shared/utils.py b/tests/system/shared/utils.py
index 78b808a458..50b99e63eb 100644
--- a/tests/system/shared/utils.py
+++ b/tests/system/shared/utils.py
@@ -322,7 +322,7 @@ def verifyOutput(string, substring, outputFrom, outputIn):
else:
test.passes("Output from " + outputFrom + " found at position " + str(index) + " of " + outputIn)
-# function that verifies the existance and the read permissions
+# function that verifies the existence and the read permissions
# of the given file path
# if the executing user hasn't the read permission it checks
# the parent folders for their execute permission
@@ -461,7 +461,7 @@ def iterateQtVersions(keepOptionsOpen=False, alreadyOnOptionsDialog=False,
t,v,tb = sys.exc_info()
currResult = None
test.fatal("Function to additionally execute on Options Dialog could not be found or "
- "an exception occured while executing it.", "%s(%s)" % (str(t), str(v)))
+ "an exception occurred while executing it.", "%s(%s)" % (str(t), str(v)))
additionalResult.append(currResult)
if not keepOptionsOpen:
clickButton(waitForObject(":Options.Cancel_QPushButton"))
@@ -524,7 +524,7 @@ def iterateKits(keepOptionsOpen=False, alreadyOnOptionsDialog=False,
t,v,tb = sys.exc_info()
currResult = None
test.fatal("Function to additionally execute on Options Dialog could not be "
- "found or an exception occured while executing it.", "%s(%s)" %
+ "found or an exception occurred while executing it.", "%s(%s)" %
(str(t), str(v)))
additionalResult.append(currResult)
if not keepOptionsOpen:
diff --git a/tests/system/shared/workarounds.py b/tests/system/shared/workarounds.py
index f1cef9a2b8..961c57fab4 100644
--- a/tests/system/shared/workarounds.py
+++ b/tests/system/shared/workarounds.py
@@ -82,12 +82,12 @@ class JIRA:
JIRA.__instance__._number = number
JIRA.__instance__.__fetchResolutionFromJira__()
- # overriden to make it possible to use JIRA just like the
+ # overridden to make it possible to use JIRA just like the
# underlying implementation (__impl)
def __getattr__(self, attr):
return getattr(self.__instance__, attr)
- # overriden to make it possible to use JIRA just like the
+ # overridden to make it possible to use JIRA just like the
# underlying implementation (__impl)
def __setattr__(self, attr, value):
return setattr(self.__instance__, attr, value)
diff --git a/tests/system/suite_editors/tst_qml_indent/test.py b/tests/system/suite_editors/tst_qml_indent/test.py
index 5f886908c3..cd59419bd2 100644
--- a/tests/system/suite_editors/tst_qml_indent/test.py
+++ b/tests/system/suite_editors/tst_qml_indent/test.py
@@ -33,7 +33,7 @@ def main():
startApplication("qtcreator" + SettingsPath)
if not startedWithoutPluginError():
return
- # using a temporary directory won't mess up a potentially exisiting
+ # using a temporary directory won't mess up a potentially existing
createNewQtQuickApplication(tempDir(), "untitled")
if not prepareQmlFile():
invokeMenuItem("File", "Save All")
diff --git a/src/plugins/projectexplorer/miniprojecttargetselector.cpp b/src/plugins/projectexplorer/miniprojecttargetselector.cpp
index 51af5ce930..269290f11f 100644
--- a/src/plugins/projectexplorer/miniprojecttargetselector.cpp
+++ b/src/plugins/projectexplorer/miniprojecttargetselector.cpp
@@ -896,7 +896,7 @@ void MiniProjectTargetSelector::doLayout(bool keepSize)
int heightWithoutKitArea = 0;
if (!onlySummary) {
// list widget heigth
int maxItemCount = m_projectListWidget->maxCount();
for (int i = TARGET; i < LAST; ++i)
maxItemCount = qMax(maxItemCount, m_listWidgets[i]->maxCount());
@@ -906,7 +906,7 @@ void MiniProjectTargetSelector::doLayout(bool keepSize)
heightWithoutKitArea = height() - oldSummaryLabelY + 1;
} else {
// Clamp the size of the listwidgets to be
- // at least as high as the the sidebar button
+ // at least as high as the sidebar button
// and at most twice as high
heightWithoutKitArea = summaryLabelHeight
+ qBound(alignedWithActionHeight,
@@ -896,7 +896,7 @@ void MiniProjectTargetSelector::doLayout(bool keepSize)
int heightWithoutKitArea = 0;
if (!onlySummary) {
- // list widget heigth
+ // list widget height
int maxItemCount = m_projectListWidget->maxCount();
for (int i = TARGET; i < LAST; ++i)